import tkinter as tk
from tkinter import ttk
from tkinter import messagebox
import webbrowser
import os

class App():
    def __init__(self):
        # Create window
        self.root = tk.Tk()
        self.root.geometry('450x450')
        self.root.title('Rhys Vault GUI')

        # Set custom icon using a PNG or JPG file
        icon_path = os.path.join('Images', 'icon', 'icon.png')
        if os.path.exists(icon_path):
            self.icon = tk.PhotoImage(file=icon_path)
            self.root.iconphoto(True, self.icon)
        else:
            messagebox.showerror("Error", "Icon file not found!")

        # Lock the window size to 450x450
        self.root.minsize(450, 450)
        self.root.maxsize(450, 450)
        
        # Main frame with padding added
        self.mainframe = tk.Frame(self.root, background='white', padx=10, pady=10)
        self.mainframe.pack(fill='both', expand=True, padx=10, pady=10)

        # Button to take you to Rhys Vault
        self.button = tk.Button(self.mainframe, text='Go to Rhys Vault', command=self.open_website)
        self.button.grid(row=1, column=0, pady=20, padx=10, sticky='ew')

        # Select specific page
        self.text = ttk.Label(self.mainframe, text='Select a specific page', background='white', font=("Brass Mono", 12))
        self.text.grid(row=3, column=0, columnspan=2, pady=10, padx=10, sticky='ew')

        # Select specific page dropdown
        rv_options = ['Home', 'Project Vault', 'Search', 'Tools Vault']
        self.set_rv_field = ttk.Combobox(self.mainframe, values=rv_options)
        self.set_rv_field.grid(row=4, column=0, pady=10, padx=10, sticky='ew')
        set_rv_button = ttk.Button(self.mainframe, text='Goto Page', command=self.set_rv)
        set_rv_button.grid(row=4, column=1, pady=10, padx=10, sticky='ew')

        # Quick Download section
        self.download_text = ttk.Label(self.mainframe, text='Quick Download', background='white', font=("Brass Mono", 12))
        self.download_text.grid(row=5, column=0, columnspan=2, pady=10, padx=10, sticky='ew')

        # Quick Download section dropdown
        download_options = ['[Project] Rhys Vault GUI', '[Project] Terminal', '[Tool] Windows Product Key Finder', '[Tool] CMD in a batch script']
        self.download_field = ttk.Combobox(self.mainframe, values=download_options)
        self.download_field.grid(row=6, column=0, pady=10, padx=10, sticky='ew')
        download_button = ttk.Button(self.mainframe, text='Download', command=self.download_item)
        download_button.grid(row=6, column=1, pady=10, padx=10, sticky='ew')

        self.root.mainloop()

    def open_website(self):
        url = 'https://rhysvault.com/'
        webbrowser.open_new(url)

    def set_rv(self):
        page_urls = {
            'Home': 'https://rhysvault.com/',
            'Search': 'https://rhysvault.com/search',
            'Project Vault': 'https://rhysvault.com/project_vault/projects',
            'Tools Vault': 'https://rhysvault.com/tools_vault/tools'
        }
        selected_page = self.set_rv_field.get()
        if selected_page in page_urls:
            url = page_urls[selected_page]
            webbrowser.open_new(url)
        else:
            messagebox.showerror("Error", "Please select a valid page.")

    def download_item(self):
        download_links = {
            '[Project] Rhys Vault GUI': 'https://rhysvault.com/Project_Vault/Downloads/Python/RV-GUI.zip',
            '[Project] Terminal': 'https://rhysvault.com/Project_Vault/Batch/Terminal/Terminal_current.zip',
            '[Tool] Windows Product Key Finder': 'https://rhysvault.com/Tools_Vault/Downloads/vbs/Windows%20Product%20Key%20Finder.zip',
            '[Tool] CMD in a batch script': 'https://rhysvault.com/Tools_Vault/Downloads/bat/CMD%20in%20batch%20file.zip'
        }
        selected_download = self.download_field.get()
        if selected_download in download_links: 
            url = download_links[selected_download]
            webbrowser.open_new(url)
        else:
            messagebox.showerror("Error", "Please select a valid download.")

if __name__ == '__main__':
    App()